Syscall

Enum Syscall 

#[non_exhaustive]
pub enum Syscall { Running, Blocked { syscall_number: i64, argument_registers: [u64; 6], stack_pointer: u64, program_counter: u64, }, }
Syscall information about the process, based on the /proc/<pid>/syscall file.

New variants to this enum may be added at any time (even without a major or minor semver bump).

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Running

The process is running, and so the values are not present



Blocked

Fields

syscall_number: i64

The syscall this process is blocked on. If the syscall_number is -1, then not blocked on a syscall (blocked for another reason). Note that the rest of the values are still filled in.

argument_registers: [u64; 6]

The argument registers

stack_pointer: u64

e.g. rsp

program_counter: u64

e.g. rip