pub struct KernelStats {
pub total: CpuTime,
pub cpu_time: Vec<CpuTime>,
pub ctxt: u64,
pub btime: u64,
pub processes: u64,
pub procs_running: Option<u32>,
pub procs_blocked: Option<u32>,
}Expand description
Kernel/system statistics, from /proc/stat
Fields
total: CpuTimeThe amount of time the system spent in various states
cpu_time: Vec<CpuTime>The amount of time that specific CPUs spent in various states
ctxt: u64The number of context switches that the system underwent
btime: u64Boot time, in number of seconds since the Epoch
processes: u64Number of forks since boot
procs_running: Option<u32>Number of processes in runnable state
(Since Linux 2.5.45)
procs_blocked: Option<u32>Number of processes blocked waiting for I/O
(Since Linux 2.5.45)