pub struct MemoryPressure {
pub some: PressureRecord,
pub full: PressureRecord,
}Expand description
Memory pressure information
Fields
some: PressureRecordThis record indicates the share of time in which at least some tasks are stalled.
full: PressureRecordThis record indicates this share of time in which all non-idle tasks are stalled simultaneously.