pub struct VmStat(pub HashMap<String, i64>);Expand description
Various virtual memory statistics
Since the exact set of statistics will vary from kernel to kernel, and because most of them are not well documented, this struct contains a HashMap instead of specific members. Consult the kernel source code for more details of this data.
Tuple Fields
0: HashMap<String, i64>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for VmStat
impl<'de> Deserialize<'de> for VmStat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromBufRead for VmStat
impl FromBufRead for VmStat
fn from_buf_read<R: BufRead>(r: R) -> ProcResult<Self>